@@ -40,7 +40,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.02;
+    our $VERSION = 1.03;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -520,7 +520,7 @@ sub debug {
     my $msgs  = shift;
 
     if ($level !~ /ERR.*|WARN.*|NOTICE|INFO.*|DEBUG/i) { # Compatibility with older versions.
-        $level = $msgs;
+        $level = $msgs;                                  # It tosses the __LINE__ argument
         $msgs  = shift;
     }
     $level = 'ERR'  if ($level eq 'ERROR');      # This allows the programmer to use either
@@ -601,7 +601,8 @@ sub debug {
     # Figure out the benchmarks, but only if it is in the prefix
     if ($self->{'PREFIX'} =~ /\%Benchmark\%/) {
         # For multiline output, only output the bench data on the first line.  Use padded spaces for the rest.
-        $thisBench  = sprintf('%7s', sprintf(' %.02f', time - $self->{$level . '_LASTSTAMP'}));
+#        $thisBench  = sprintf('%7s', sprintf(' %.02f', time - $self->{$level . '_LASTSTAMP'}));
+        $thisBench  = sprintf('%7s', sprintf(' %.02f', time - $self->{'ANY_LASTSTAMP'}));
         $thisBench2 = ' ' x length($thisBench);
     }
     my $first = 1;                         # Set the first line flag.
@@ -628,6 +629,7 @@ sub debug {
         }
         $first = 0;                        # Clear the first line flag.
     }
+    $self->{'ANY_LASTSTAMP'}       = time;
     $self->{$level . '_LASTSTAMP'} = time;
 }
 
@@ -841,6 +843,8 @@ sub DEBUGMAX {
     $self->debug('DEBUGMAX',@_);
 }
 
+1;
+
 =head1 CAVEATS
 
 Since it is possible to duplicate the object in a fork or thread, the output
@@ -874,7 +878,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 1.00    (June 15, 2015)
+Version 1.03    (July 10, 2015 Happy Birthday to me!)
 
 =head1 BUGS
 
@@ -959,4 +963,3 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1;
